==> le-1.9.2.tar.bz2: le-1.9.2/src/textpoin.h <==
/*
 * Copyright (c) 1993-1997 by Alexander V. Lukyanov (lav@yars.free.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: textpoin.h,v 1.7 2000/09/04 08:19:02 lav Exp $ */

#ifndef TEXTPOINT_H
#define TEXTPOINT_H

#include <string.h>

#define  COLUNDEFINED      1
#define  LINEUNDEFINED     2

class TextPoint
{
   offs  offset;
   num   line,col;
   int   flags;
   static TextPoint cached_array[];
   static int cached_array_ptr;

   TextPoint   *next;
   static TextPoint   *base;

   void  AddTextPoint();
   void  DeleteTextPoint();

   void  FindOffset();
   void  FindLineCol();

   void  Init() {
      offset=line=col=flags=0;
   }

public:
   offs  Offset()
   {
      return(offset);
   }
   num   Line()
   {
      if(flags&LINEUNDEFINED)
         FindLineCol();
      return(line);
   }
   num   Col()
   {
      if(flags&(COLUNDEFINED|LINEUNDEFINED))
         FindLineCol();
      return(col);
   }
   num	 LineSimple()
   {
      if(flags&LINEUNDEFINED)
         return -1;
      return(line);
   }
   num	 ColSimple()
   {
      if(flags&(COLUNDEFINED|LINEUNDEFINED))
         return -1;
      return(col);
   }

   TextPoint();
   TextPoint(offs);
   TextPoint(num,num);
   TextPoint(const TextPoint&);
   TextPoint(offs,num,num);

   void CacheTextPoint();

   ~TextPoint();

   const TextPoint& operator=(const TextPoint& tp)
   {
      offset=tp.offset;
      line=tp.line;
      col=tp.col;
      flags=tp.flags;
      return(*this);
   }
   const TextPoint& operator+=(num shift);
   const TextPoint& operator-=(num shift)
   {
      return(*this+=-shift);
   }
   operator offs() const
   {
      return(offset);
   }

   static TextPoint ForcedLineCol(num l,num c);

   static   void  ResetTextPoints();
   static   void  OrFlags(int mask);

   friend   int   InsertBlock(char *,num,char *,num);
   friend   int   DeleteBlock(num,num);
   friend   int   ReplaceBlock(char *,num);
};

extern TextPoint  CurrentPos;
extern TextPoint  ScreenTop;
extern TextPoint  BlockBegin;
extern TextPoint  BlockEnd;
extern TextPoint  TextEnd;
extern TextPoint  TextBegin;

#define ScrPtr  ScreenTop.Offset()
#define ScrLine ScreenTop.Line()

#endif

==> le-1.14.3.tar.bz2: le-1.14.3/src/textpoin.h <==
/*
 * Copyright (c) 1993-1997 by Alexander V. Lukyanov (lav@yars.free.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: textpoin.h,v 1.9 2008/09/02 05:01:48 lav Exp $ */

#ifndef TEXTPOINT_H
#define TEXTPOINT_H

#include <string.h>

#define  COLUNDEFINED      1
#define  LINEUNDEFINED     2

class TextPoint
{
   offs  offset;
   num   line,col;
   int   flags;
   static TextPoint cached_array[];
   static int cached_array_ptr;

   TextPoint   *next;
   static TextPoint   *base;

   void  AddTextPoint();
   void  DeleteTextPoint();

   void  FindOffset();
   void  FindLineCol();

   void  Init() {
      offset=line=col=flags=0;
   }

public:
   offs  Offset()
   {
      return(offset);
   }
   num   Line();
   num   Col();

   num	 LineSimple()
   {
      if(flags&LINEUNDEFINED)
         return -1;
      return(line);
   }
   num	 ColSimple()
   {
      if(flags&(COLUNDEFINED|LINEUNDEFINED))
         return -1;
      return(col);
   }

   TextPoint();
   TextPoint(offs);
   TextPoint(num,num);
   TextPoint(const TextPoint&);
   TextPoint(offs,num,num);

   void CacheTextPoint();

   ~TextPoint();

   const TextPoint& operator=(const TextPoint& tp)
   {
      offset=tp.offset;
      line=tp.line;
      col=tp.col;
      flags=tp.flags;
      return(*this);
   }
   const TextPoint& operator+=(num shift);
   const TextPoint& operator-=(num shift)
   {
      return(*this+=-shift);
   }
   operator offs() const
   {
      return(offset);
   }

   static TextPoint ForcedLineCol(num l,num c);

   static   void  ResetTextPoints();
   static   void  OrFlags(int mask);

   friend   int   InsertBlock(const char *,num,const char *,num);
   friend   int   DeleteBlock(num,num);
   friend   int   ReplaceBlock(const char *,num);
};

extern TextPoint  CurrentPos;
extern TextPoint  ScreenTop;
extern TextPoint  BlockBegin;
extern TextPoint  BlockEnd;
extern TextPoint  TextEnd;
extern TextPoint  TextBegin;

#define ScrPtr  ScreenTop.Offset()
#define ScrLine ScreenTop.Line()

#endif
